GalaRP (`Gala <http://gala.adrian.pw/en/latest/>`_ + RP) is an analytical framework for gaseous evolution under ram pressure.

|logo|



.. |logo| image:: https://hsouch.github.io//images/Galarp-Logo.png


.. image:: https://readthedocs.org/projects/galarp/badge/?version=latest
    :target: https://galarp.readthedocs.io/en/latest/?badge=latest
    :alt: Documentation Status

You can install Galarp easily using ``pip``::

    pip install galarp

The documentation for GalaRP is available at https://galarp.readthedocs.io/en/latest/. Suggestions and contributions
are welcomed through pull requests or issues.